package com.sobot.chat.widget.emoji;

import android.content.Context;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;


/**
 * 36个 Emoji
 * 参考 https://apps.timwhitlock.info/unicode/inspect?s=%F0%9F%98%83%F0%9F%98%8A%E2%98%BA%F0%9F%98%9A%F0%9F%98%98%F0%9F%98%81%F0%9F%98%9D%F0%9F%98%8B%F0%9F%98%8D%F0%9F%98%8F%F0%9F%98%8E%F0%9F%98%8C%F0%9F%98%89%F0%9F%98%93%F0%9F%98%A3%F0%9F%98%B0%F0%9F%98%94%F0%9F%98%B5%F0%9F%98%82%F0%9F%98%A2%F0%9F%98%AD%F0%9F%98%A8%F0%9F%98%B1%F0%9F%98%B7%F0%9F%98%A0%E2%9D%A4%EF%B8%8F%F0%9F%92%94%F0%9F%91%8D%F0%9F%91%8C%E2%9C%8C%F0%9F%91%8F%F0%9F%A4%9D%F0%9F%99%8F%F0%9F%92%AA%F0%9F%8E%89%E2%AD%90
 */
public enum DisplayEmojiRules {
    QQBIAOQING0("\uD83D\uDE03", "SMILING FACE WITH OPEN MOUTH"),
    QQBIAOQING1("\uD83D\uDE0A", "SMILING FACE WITH SMILING EYES"),
    QQBIAOQING2("☺", "WHITE SMILING FACE"),
    QQBIAOQING3("\uD83D\uDE1A", "KISSING FACE WITH CLOSED EYES"),
    QQBIAOQING4("\uD83D\uDE18", "FACE THROWING A KISS"),
    QQBIAOQING5("\uD83D\uDE01", "GRINNING FACE WITH SMILING EYES"),
    QQBIAOQING6("\uD83D\uDE1D", "FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES"),
    QQBIAOQING7("\uD83D\uDE0B", "FACE SAVOURING DELICIOUS FOOD"),
    QQBIAOQING8("\uD83D\uDE0D", "SMILING FACE WITH HEART-SHAPED EYES"),
    QQBIAOQING9("\uD83D\uDE0F", "SMIRKING FACE"),
    QQBIAOQING10("\uD83D\uDE0E", "SMILING FACE WITH SUNGLASSES"),
    QQBIAOQING11("\uD83D\uDE0C", "RELIEVED FACE"),
    QQBIAOQING12("\uD83D\uDE09", "WINKING FACE"),
    QQBIAOQING13("\uD83D\uDE13", "FACE WITH COLD SWEAT"),
    QQBIAOQING14("\uD83D\uDE23", "PERSEVERING FACE"),
    QQBIAOQING15("\uD83D\uDE30", "FACE WITH OPEN MOUTH AND COLD SWEAT"),
    QQBIAOQING16("\uD83D\uDE14", "PENSIVE FACE"),
    QQBIAOQING17("\uD83D\uDE35", "DIZZY FACE"),
    QQBIAOQING18("\uD83D\uDE02", "FACE WITH TEARS OF JOY"),
    QQBIAOQING19("\uD83D\uDE22", "CRYING FACE"),
    QQBIAOQING20("\uD83D\uDE2D", "LOUDLY CRYING FACE"),
    QQBIAOQING21("\uD83D\uDE28", "FEARFUL FACE"),
    QQBIAOQING22("\uD83D\uDE31", "FACE SCREAMING IN FEAR"),
    QQBIAOQING23("\uD83D\uDE37", "FACE WITH MEDICAL MASK"),
    QQBIAOQING24("\uD83D\uDE20", "ANGRY FACE"),
    QQBIAOQING25("❤️", "HEAVY BLACK HEART"),
    QQBIAOQING26("\uD83D\uDC94", "BROKEN HEART"),
    QQBIAOQING27("\uD83D\uDC4D", "THUMBS UP SIGN"),
    QQBIAOQING28("\uD83D\uDC4C", "OK HAND SIGN"),
    QQBIAOQING29("✌️", "VICTORY HAND"),
    QQBIAOQING30("\uD83D\uDC4F", "CLAPPING HANDS SIGN"),
    QQBIAOQING31("\uD83E\uDD1D", "HANDSHAKE"),
    QQBIAOQING32("\uD83D\uDE4F", "PERSON WITH FOLDED HANDS"),
    QQBIAOQING33("\uD83D\uDCAA", "FLEXED BICEPS"),
    QQBIAOQING34("\uD83C\uDF89", "PARTY POPPER"),
    QQBIAOQING35("⭐", "WHITE MEDIUM STAR");

    /*********************************
     * 操作
     **************************************/
    private String emojiCode;
    private String emojiDes;
    private static Map<String, String> sEmojiMap;

    private DisplayEmojiRules(String emojiCode, String emojiDes) {
        this.emojiDes = emojiDes;
        this.emojiCode = emojiCode;
    }

    public String getEmojiDes() {
        return emojiDes;
    }

    public void setEmojiDes(String emojiDes) {
        this.emojiDes = emojiDes;
    }

    public String getEmojiCode() {
        return emojiCode;
    }

    public void setEmojiCode(String emojiCode) {
        this.emojiCode = emojiCode;
    }

    /**
     * 提高效率，忽略线程安全
     */
    public static Map<String, String> getMapAll(Context context) {
        if (sEmojiMap == null) {
            sEmojiMap = new HashMap<>();
            for (DisplayEmojiRules data : values()) {
                sEmojiMap.put(data.getEmojiCode(), data.getEmojiDes());
            }
        }
        return sEmojiMap;
    }

    public static ArrayList<EmojiconNew> getListAll(Context context) {
        ArrayList<EmojiconNew> sEmojiList = new ArrayList<>();
        for (DisplayEmojiRules data : values()) {
            sEmojiList.add(new EmojiconNew(data.getEmojiCode(), data.getEmojiDes()));
        }
        return sEmojiList;
    }
}